@@ -321,11 +321,13 @@ class AdvancedSearchView(BaseListView):
         query_dc = self.get_request_data()
         Q_add_ls = self.get_Q_add_ls()
         if Q_add_ls:
-            original_qs_ls = get_base_queryset(super().get_queryset())
+            sp_qs_ls = super().get_queryset()
             add_q = AddQ(Q_add_ls=Q_add_ls)
             qs = add_q.get_QS()
-            self.queryset = original_qs_ls.filter(qs)
-            return self.queryset
+            if not isinstance(sp_qs_ls, QuerySet):
+                sp_qs_ls = get_base_queryset(sp_qs_ls)
+            ret = sp_qs_ls.filter(qs)
+            return ret
 
         search_condition_ls = query_dc.get('search_condition_ls', [])
         if search_condition_ls:
