@@ -34,8 +34,10 @@ def version():
         - 加上`auth.MyValidationError`, 修复验证模块报错bug
         - 简化部分代码: 将(获取self.key or 获取query_dc.key)的方法统一  # 2.1.9
         - 修复`_get_key_from_query_dc_or_self`的关键bug!     # 2.1.10
+        - 拓展`get_MySubQuery`方法, 对`annotate`生成的字段生效      # 2.1.11
+        - 在`get_abs_order_type_ls`方法中处理str类型数据
     """
-    v = "2.1.10"     # 正式版: 2.1.9
+    v = "2.1.11"     # 正式版: 2.1.10
     return v
 
 
